@@ -4,16 +4,20 @@ OC.L10N.register(
     "You created two-factor backup codes for your account" : "Creaste códigos de respaldo de dos factores para tu cuenta",
     "Second-factor backup codes" : "Códigos de respaldo del segundo factor",
     "Generate backup codes" : "Generar los códigos de respaldo",
+    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Habilitó la autentificación de dos factores pero aún no ha generado los códigos de respaldo. Éstos son necesarios para acceder a su cuenta en caso de que pierda del segundo factor.",
     "Backup code" : "Código de respaldo",
     "Use backup code" : "Usa el código de respaldo",
     "Two factor backup codes" : "Códigos de respaldo de dos factores",
     "A two-factor auth backup codes provider" : "Un proveedor de códigos de respaldo para autenticación de dos-factores",
-    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Estos son tus códigos de respaldo. Por favor resguárdalos y/o imprímelos ya que no podrás leerlos otra vez después.",
+    "An error occurred while generating your backup codes" : "Se presentó un error al generar tus códigos de respaldo. ",
+    "Backup codes have been generated. {used} of {total} codes have been used." : "Se generaron los códigos de respaldo. Se han utilizado {used} de {total} códigos.",
+    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later." : "Estos son sus códigos de respaldo. Por favor guárdelos y/o imprímalos ya que no podrá leerlos después.",
     "Save backup codes" : "Guardar códigos de respaldo",
     "Print backup codes" : "Imprimir códigos de respaldo",
     "Regenerate backup codes" : "Regenerar códigos de respaldo",
     "If you regenerate backup codes, you automatically invalidate old codes." : "Si regeneras los códigos de respaldo, automáticamente invalidarás los anteriores. ",
-    "An error occurred while generating your backup codes" : "Se presentó un error al generar tus códigos de respaldo. ",
+    "{name} backup codes" : "Códigos de respaldo {name}",
+    "Use one of the backup codes you saved when setting up two-factor authentication." : "Utilice uno de los códigos de respaldo que guardó al configurar la autentificación de dos factores.",
     "Submit" : "Enviar"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
